
# look for and purge old records every hour
#   1209600 = 2 weeks old

# m h  dom mon dow   command
#0 *     * * *     www-data cd /usr/share/loganalyzer/cron && php ./maintenance.php cleandata Source1 olderthan 1209600 > /dev/null

